@@ -27,7 +27,6 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkmarshal.h>
 
 #include <libxfce4util/libxfce4util.h>
 
@@ -517,7 +516,7 @@ rstto_icon_bar_init (RsttoIconBar *icon_bar)
     pango_layout_set_ellipsize (icon_bar->priv->layout,
             PANGO_ELLIPSIZE_END);
 
-    GTK_WIDGET_UNSET_FLAGS (icon_bar, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus (GTK_WIDGET (icon_bar), FALSE);
 
     rstto_icon_bar_set_adjustments (icon_bar, NULL, NULL);
 
@@ -643,10 +642,10 @@ rstto_icon_bar_style_set (
 
     (*GTK_WIDGET_CLASS (rstto_icon_bar_parent_class)->style_set) (widget, previous_style);
 
-    if (GTK_WIDGET_REALIZED (widget))
+    if (gtk_widget_get_realized (widget))
     {
         gdk_window_set_background (icon_bar->priv->bin_window,
-                &widget->style->base[widget->state]);
+                &(gtk_widget_get_style (widget)->base[gtk_widget_get_state (widget)]));
     }
 }
 
@@ -658,28 +657,34 @@ rstto_icon_bar_realize (GtkWidget *widget)
     GdkWindowAttr attributes;
     RsttoIconBar   *icon_bar = RSTTO_ICON_BAR (widget);
     gint          attributes_mask;
+    GtkAllocation allocation;
+    GdkWindow    *window;
+    GtkStyle     *style;
 
-    GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+    gtk_widget_set_realized (widget, TRUE);
+
+    gtk_widget_get_allocation (widget, &allocation);
 
     attributes.window_type = GDK_WINDOW_CHILD;
-    attributes.x = widget->allocation.x;
-    attributes.y = widget->allocation.y;
-    attributes.width = widget->allocation.width;
-    attributes.height = widget->allocation.height;
+    attributes.x = allocation.x;
+    attributes.y = allocation.y;
+    attributes.width = allocation.width;
+    attributes.height = allocation.height;
     attributes.wclass = GDK_INPUT_OUTPUT;
     attributes.visual = gtk_widget_get_visual (widget);
     attributes.colormap = gtk_widget_get_colormap (widget);
     attributes.event_mask = GDK_VISIBILITY_NOTIFY_MASK;
     attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
-    widget->window = gdk_window_new (gtk_widget_get_parent_window (widget),
+    window = gdk_window_new (gtk_widget_get_parent_window (widget),
             &attributes, attributes_mask);
-    gdk_window_set_user_data (widget->window, widget);
+    gtk_widget_set_window (widget, window);
+    gdk_window_set_user_data (window, widget);
 
     attributes.x = 0;
     attributes.y = 0;
-    attributes.width = MAX (icon_bar->priv->width, widget->allocation.width);
-    attributes.height = MAX (icon_bar->priv->height, widget->allocation.height);
+    attributes.width = MAX (icon_bar->priv->width, allocation.width);
+    attributes.height = MAX (icon_bar->priv->height, allocation.height);
     attributes.event_mask = (GDK_SCROLL_MASK
             | GDK_EXPOSURE_MASK
             | GDK_LEAVE_NOTIFY_MASK
@@ -691,13 +696,13 @@ rstto_icon_bar_realize (GtkWidget *widget)
             | gtk_widget_get_events (widget);
     attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
-    icon_bar->priv->bin_window = gdk_window_new (widget->window,
-            &attributes, attributes_mask);
+    icon_bar->priv->bin_window = gdk_window_new (window, &attributes, attributes_mask);
     gdk_window_set_user_data (icon_bar->priv->bin_window, widget);
 
-    widget->style = gtk_style_attach (widget->style, widget->window);
-    gdk_window_set_background (widget->window, &widget->style->base[widget->state]);
-    gdk_window_set_background (icon_bar->priv->bin_window, &widget->style->base[widget->state]);
+    style = gtk_style_attach (gtk_widget_get_style (widget), window);
+    gtk_widget_set_style (widget, style);
+    gdk_window_set_background (window, &(gtk_widget_get_style (widget)->base[gtk_widget_get_state (widget)]));
+    gdk_window_set_background (icon_bar->priv->bin_window, &(gtk_widget_get_style (widget)->base[gtk_widget_get_state (widget)]));
     gdk_window_show (icon_bar->priv->bin_window);
 }
 
@@ -775,14 +780,14 @@ rstto_icon_bar_size_allocate (
     gdouble value = 0.0;
     gdouble page_size = 0.0;
 
-    widget->allocation = *allocation;
+    gtk_widget_set_allocation (widget, allocation);
 
     if (!icon_bar->priv->active_item)
         g_warning ("thumbnail bar shown when no images are available");
 
-    if (GTK_WIDGET_REALIZED (widget))
+    if (gtk_widget_get_realized (widget))
     {
-        gdk_window_move_resize (widget->window,
+        gdk_window_move_resize (gtk_widget_get_window (widget),
                 allocation->x,
                 allocation->y,
                 allocation->width,
@@ -795,32 +800,32 @@ rstto_icon_bar_size_allocate (
     if (icon_bar->priv->orientation == GTK_ORIENTATION_VERTICAL)
     {
         value = gtk_adjustment_get_value (icon_bar->priv->vadjustment);
-        value = value / icon_bar->priv->vadjustment->upper * MAX (allocation->height, icon_bar->priv->height);
+        value = value / gtk_adjustment_get_upper (icon_bar->priv->vadjustment) * MAX (allocation->height, icon_bar->priv->height);
     }
     else
     {
         value = gtk_adjustment_get_value (icon_bar->priv->hadjustment);
-        value = value / icon_bar->priv->hadjustment->upper * MAX (allocation->width, icon_bar->priv->width);
+        value = value / gtk_adjustment_get_upper (icon_bar->priv->hadjustment) * MAX (allocation->width, icon_bar->priv->width);
     }
 
-    icon_bar->priv->hadjustment->page_size = allocation->width;
-    icon_bar->priv->hadjustment->page_increment = allocation->width * 0.9;
-    icon_bar->priv->hadjustment->step_increment = allocation->width * 0.1;
-    icon_bar->priv->hadjustment->lower = 0;
-    icon_bar->priv->hadjustment->upper = MAX (allocation->width, icon_bar->priv->width);
+    gtk_adjustment_set_page_size (icon_bar->priv->hadjustment, allocation->width);
+    gtk_adjustment_set_page_increment (icon_bar->priv->hadjustment, allocation->width * 0.9);
+    gtk_adjustment_set_step_increment (icon_bar->priv->hadjustment, allocation->width * 0.1);
+    gtk_adjustment_set_lower (icon_bar->priv->hadjustment, 0);
+    gtk_adjustment_set_upper (icon_bar->priv->hadjustment, MAX (allocation->width, icon_bar->priv->width));
 
-    icon_bar->priv->vadjustment->page_size = allocation->height;
-    icon_bar->priv->vadjustment->page_increment = allocation->height * 0.9;
-    icon_bar->priv->vadjustment->step_increment = allocation->height * 0.1;
-    icon_bar->priv->vadjustment->lower = 0;
-    icon_bar->priv->vadjustment->upper = MAX (allocation->height, icon_bar->priv->height);
+    gtk_adjustment_set_page_size (icon_bar->priv->vadjustment, allocation->height);
+    gtk_adjustment_set_page_increment (icon_bar->priv->vadjustment, allocation->height * 0.9);
+    gtk_adjustment_set_step_increment (icon_bar->priv->vadjustment, allocation->height * 0.1);
+    gtk_adjustment_set_lower (icon_bar->priv->vadjustment, 0);
+    gtk_adjustment_set_upper (icon_bar->priv->vadjustment, MAX (allocation->height, icon_bar->priv->height));
 
 
     if (icon_bar->priv->orientation == GTK_ORIENTATION_VERTICAL)
     {
         icon_bar->priv->width = allocation->width;
         icon_bar->priv->item_width = icon_bar->priv->width;
-        icon_bar->priv->hadjustment->value = 0;
+        gtk_adjustment_set_value (icon_bar->priv->hadjustment, 0);
 
         page_size = gtk_adjustment_get_page_size (icon_bar->priv->vadjustment);
 
@@ -828,13 +833,10 @@ rstto_icon_bar_size_allocate (
         if (icon_bar->priv->auto_center == TRUE)
         {
             if (icon_bar->priv->active_item)
-            {
                 value = icon_bar->priv->active_item->index * icon_bar->priv->item_height;// - ((page_size-icon_bar->priv->item_height)/2);
-            }
-		
 
-            if (value > (gtk_adjustment_get_upper (icon_bar->priv->vadjustment)-page_size))
-                value = (gtk_adjustment_get_upper (icon_bar->priv->vadjustment)-page_size);
+            if (value > (gtk_adjustment_get_upper (icon_bar->priv->vadjustment) - page_size))
+                value = (gtk_adjustment_get_upper (icon_bar->priv->vadjustment) - page_size);
 
             gtk_adjustment_set_value (icon_bar->priv->vadjustment, value);
             rstto_icon_bar_adjustment_changed (icon_bar, icon_bar->priv->vadjustment);
@@ -842,10 +844,9 @@ rstto_icon_bar_size_allocate (
         }
         else
         {
-            if (value > (gtk_adjustment_get_upper (icon_bar->priv->vadjustment)-page_size))
-            {
-                value = gtk_adjustment_get_upper (icon_bar->priv->vadjustment)-page_size;
-            }
+            if (value > (gtk_adjustment_get_upper (icon_bar->priv->vadjustment) - page_size))
+                value = gtk_adjustment_get_upper (icon_bar->priv->vadjustment) - page_size;
+
             gtk_adjustment_set_value (icon_bar->priv->vadjustment, value);
             rstto_icon_bar_adjustment_changed (icon_bar, icon_bar->priv->vadjustment);
             rstto_icon_bar_adjustment_changed (icon_bar, icon_bar->priv->hadjustment);
@@ -855,17 +856,18 @@ rstto_icon_bar_size_allocate (
     {
         icon_bar->priv->height = allocation->height;
         icon_bar->priv->item_height = icon_bar->priv->height;
-        icon_bar->priv->vadjustment->value = 0;
+        gtk_adjustment_set_value (icon_bar->priv->vadjustment, 0);
 
         page_size = gtk_adjustment_get_page_size (icon_bar->priv->hadjustment);
 
         /* If auto-center is true, center the selected item */
         if (icon_bar->priv->auto_center == TRUE)
         {
-            value = icon_bar->priv->active_item->index * icon_bar->priv->item_width - ((page_size-icon_bar->priv->item_width)/2);
+            if (icon_bar->priv->active_item)
+                value = icon_bar->priv->active_item->index * icon_bar->priv->item_width - ((page_size-icon_bar->priv->item_width)/2);
 
-            if (value > (gtk_adjustment_get_upper (icon_bar->priv->hadjustment)-page_size))
-                value = (gtk_adjustment_get_upper (icon_bar->priv->hadjustment)-page_size);
+            if (value > (gtk_adjustment_get_upper (icon_bar->priv->hadjustment) - page_size))
+                value = (gtk_adjustment_get_upper (icon_bar->priv->hadjustment) - page_size);
 
             gtk_adjustment_set_value (icon_bar->priv->hadjustment, value);
             rstto_icon_bar_adjustment_changed (icon_bar, icon_bar->priv->vadjustment);
@@ -873,10 +875,9 @@ rstto_icon_bar_size_allocate (
         }
         else
         {
-            if (value > (gtk_adjustment_get_upper (icon_bar->priv->hadjustment)-page_size))
-            {
-                value = gtk_adjustment_get_upper (icon_bar->priv->hadjustment)-page_size;
-            }
+            if (value > (gtk_adjustment_get_upper (icon_bar->priv->hadjustment) - page_size))
+                value = gtk_adjustment_get_upper (icon_bar->priv->hadjustment) - page_size;
+
             gtk_adjustment_set_value (icon_bar->priv->hadjustment, value);
             rstto_icon_bar_adjustment_changed (icon_bar, icon_bar->priv->vadjustment);
             rstto_icon_bar_adjustment_changed (icon_bar, icon_bar->priv->hadjustment);
@@ -1046,7 +1047,7 @@ rstto_icon_bar_button_press (
 
     icon_bar = RSTTO_ICON_BAR (widget);
 
-    if (G_UNLIKELY (!GTK_WIDGET_HAS_FOCUS (widget)))
+    if (G_UNLIKELY (!gtk_widget_has_focus (widget)))
         gtk_widget_grab_focus (widget);
 
     if (event->button == 1 && event->type == GDK_BUTTON_PRESS)
@@ -1113,7 +1114,8 @@ rstto_icon_bar_set_adjustments (
     {
         icon_bar->priv->hadjustment = hadj;
         g_object_ref (icon_bar->priv->hadjustment);
-        gtk_object_sink (GTK_OBJECT (icon_bar->priv->hadjustment));
+        // TODO: is this needed?
+        g_object_ref_sink (icon_bar->priv->hadjustment);
 
         g_signal_connect (icon_bar->priv->hadjustment, "value_changed",
                 G_CALLBACK (cb_rstto_icon_bar_adjustment_value_changed), icon_bar);
@@ -1124,7 +1126,8 @@ rstto_icon_bar_set_adjustments (
     {
         icon_bar->priv->vadjustment = vadj;
         g_object_ref (icon_bar->priv->vadjustment);
-        gtk_object_sink (GTK_OBJECT (icon_bar->priv->vadjustment));
+        // TODO: is this needed?
+        g_object_ref_sink (icon_bar->priv->vadjustment);
 
         g_signal_connect (icon_bar->priv->vadjustment, "value_changed",
                 G_CALLBACK (cb_rstto_icon_bar_adjustment_value_changed), icon_bar);
@@ -1142,7 +1145,7 @@ cb_rstto_icon_bar_adjustment_value_changed (
         GtkAdjustment *adjustment,
         RsttoIconBar  *icon_bar)
 {
-    if (GTK_WIDGET_REALIZED (icon_bar))
+    if (gtk_widget_get_realized (GTK_WIDGET (icon_bar)))
     {
         /* Set auto_center to false, this should be the default behaviour
          * in case a user changes the value of the adjustments.
@@ -1154,8 +1157,8 @@ cb_rstto_icon_bar_adjustment_value_changed (
         icon_bar->priv->auto_center = FALSE;
 
         gdk_window_move (icon_bar->priv->bin_window,
-                - icon_bar->priv->hadjustment->value,
-                - icon_bar->priv->vadjustment->value);
+                - gtk_adjustment_get_value (icon_bar->priv->hadjustment),
+                - gtk_adjustment_get_value (icon_bar->priv->vadjustment));
 
         gdk_window_process_updates (icon_bar->priv->bin_window, TRUE);
     }
@@ -1197,7 +1200,7 @@ rstto_icon_bar_queue_draw_item (
 {
     GdkRectangle area;
 
-    if (GTK_WIDGET_REALIZED (icon_bar))
+    if (gtk_widget_get_realized (GTK_WIDGET (icon_bar)))
     {
         if (icon_bar->priv->orientation == GTK_ORIENTATION_VERTICAL)
         {
@@ -1228,12 +1231,12 @@ rstto_icon_bar_paint_item (
     const GdkPixbuf *pixbuf = NULL;
     GdkColor        *border_color;
     GdkColor        *fill_color;
-    GdkGC           *gc;
+    cairo_t         *cr;
     gint             focus_width;
     gint             focus_pad;
     gint             x, y;
     gint             px, py;
-    gint             pixbuf_height, pixbuf_width;
+    gint             pixbuf_height = 0, pixbuf_width = 0;
     RsttoFile       *file;
     GtkTreeIter      iter;
 
@@ -1292,34 +1295,36 @@ rstto_icon_bar_paint_item (
 
         if (fill_color == NULL)
         {
-            fill_color = gdk_color_copy (&GTK_WIDGET (icon_bar)->style->base[GTK_STATE_SELECTED]);
+            fill_color = gdk_color_copy (&(gtk_widget_get_style (GTK_WIDGET (icon_bar))->base[GTK_STATE_SELECTED]));
             gdk_color_parse ("#c1d2ee", fill_color);
         }
 
         if (border_color == NULL)
         {
-            border_color = gdk_color_copy (&GTK_WIDGET (icon_bar)->style->base[GTK_STATE_SELECTED]);
+            border_color = gdk_color_copy (&(gtk_widget_get_style (GTK_WIDGET (icon_bar))->base[GTK_STATE_SELECTED]));
             gdk_color_parse ("#316ac5", border_color);
         }
 
-        gc = gdk_gc_new (icon_bar->priv->bin_window);
-        gdk_gc_set_clip_rectangle (gc, area);
-        gdk_gc_set_rgb_fg_color (gc, fill_color);
-        gdk_draw_rectangle (icon_bar->priv->bin_window, gc, TRUE,
-                x + focus_pad + focus_width,
-                y + focus_pad + focus_width,
-                icon_bar->priv->item_width - 2 * (focus_width + focus_pad),
-                icon_bar->priv->item_height - 2 * (focus_width + focus_pad));
-        gdk_gc_set_rgb_fg_color (gc, border_color);
-        gdk_gc_set_line_attributes (gc, focus_width, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
-        gdk_draw_rectangle (icon_bar->priv->bin_window, gc, FALSE,
-                x + focus_pad + focus_width / 2,
-                y + focus_pad + focus_width / 2,
-                icon_bar->priv->item_width - (2 * focus_pad + focus_width),
-                icon_bar->priv->item_height - (2 * focus_pad + focus_width));
+        cr = gdk_cairo_create (icon_bar->priv->bin_window);
+        gdk_cairo_rectangle (cr, area);
+        cairo_clip (cr);
+        cairo_set_source_rgb (cr, fill_color->red/65535., fill_color->green/65535., fill_color->blue/65535.);
+        cairo_rectangle (cr, x + focus_pad + focus_width, y + focus_pad + focus_width,
+                         icon_bar->priv->item_width - 2 * (focus_width + focus_pad),
+                         icon_bar->priv->item_height - 2 * (focus_width + focus_pad));
+        cairo_fill (cr);
+        cairo_set_source_rgb (cr, border_color->red/65535., border_color->green/65535., border_color->blue/65535.);
+        cairo_set_line_width (cr, focus_width);
+        cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
+        cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
+        cairo_rectangle (cr, x + focus_pad + focus_width / 2, y + focus_pad + focus_width / 2,
+                         icon_bar->priv->item_width - (2 * focus_pad + focus_width),
+                         icon_bar->priv->item_height - (2 * focus_pad + focus_width));
+        cairo_stroke (cr);
+        cairo_destroy (cr);
+
         gdk_color_free (border_color);
         gdk_color_free (fill_color);
-        g_object_unref (gc);
     }
     else if (icon_bar->priv->cursor_item == item)
     {
@@ -1330,44 +1335,45 @@ rstto_icon_bar_paint_item (
 
         if (fill_color == NULL)
         {
-            fill_color = gdk_color_copy (&GTK_WIDGET (icon_bar)->style->base[GTK_STATE_SELECTED]);
+            fill_color = gdk_color_copy (&(gtk_widget_get_style (GTK_WIDGET (icon_bar))->base[GTK_STATE_SELECTED]));
             gdk_color_parse ("#e0e8f6", fill_color);
         }
 
         if (border_color == NULL)
         {
-            border_color = gdk_color_copy (&GTK_WIDGET (icon_bar)->style->base[GTK_STATE_SELECTED]);
+            border_color = gdk_color_copy (&(gtk_widget_get_style (GTK_WIDGET (icon_bar))->base[GTK_STATE_SELECTED]));
             gdk_color_parse ("#98b4e2", border_color);
         }
 
-        gc = gdk_gc_new (icon_bar->priv->bin_window);
-        gdk_gc_set_clip_rectangle (gc, area);
-        gdk_gc_set_rgb_fg_color (gc, fill_color);
-        gdk_draw_rectangle (icon_bar->priv->bin_window, gc, TRUE,
-                x + focus_pad + focus_width,
-                y + focus_pad + focus_width,
-                icon_bar->priv->item_width - 2 * (focus_width + focus_pad),
-                icon_bar->priv->item_height - 2 * (focus_width + focus_pad));
-        gdk_gc_set_rgb_fg_color (gc, border_color);
-        gdk_gc_set_line_attributes (gc, focus_width, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
-        gdk_draw_rectangle (icon_bar->priv->bin_window, gc, FALSE,
-                x + focus_pad + focus_width / 2,
-                y + focus_pad + focus_width / 2,
-                icon_bar->priv->item_width - (2 * focus_pad + focus_width),
-                icon_bar->priv->item_height - (2 * focus_pad + focus_width));
+        cr = gdk_cairo_create (icon_bar->priv->bin_window);
+        gdk_cairo_rectangle (cr, area);
+        cairo_clip (cr);
+        cairo_set_source_rgb (cr, fill_color->red/65535., fill_color->green/65535., fill_color->blue/65535.);
+        cairo_rectangle (cr, x + focus_pad + focus_width, y + focus_pad + focus_width,
+                         icon_bar->priv->item_width - 2 * (focus_width + focus_pad),
+                         icon_bar->priv->item_height - 2 * (focus_width + focus_pad));
+        cairo_fill (cr);
+        cairo_set_source_rgb (cr, border_color->red/65535., border_color->green/65535., border_color->blue/65535.);
+        cairo_set_line_width (cr, focus_width);
+        cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
+        cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
+        cairo_rectangle (cr, x + focus_pad + focus_width / 2, y + focus_pad + focus_width / 2,
+                         icon_bar->priv->item_width - (2 * focus_pad + focus_width),
+                         icon_bar->priv->item_height - (2 * focus_pad + focus_width));
+        cairo_stroke (cr);
+        cairo_destroy (cr);
+
         gdk_color_free (border_color);
         gdk_color_free (fill_color);
-        g_object_unref (gc);
     }
 
 
     if (NULL != pixbuf)
     {
-        gdk_draw_pixbuf (icon_bar->priv->bin_window, NULL, pixbuf, 0, 0,
-                px, py, 
-                pixbuf_width, pixbuf_height,
-                GDK_RGB_DITHER_NORMAL,
-                pixbuf_width, pixbuf_height);
+        cr = gdk_cairo_create (icon_bar->priv->bin_window);
+        gdk_cairo_set_source_pixbuf (cr, pixbuf, px, py);
+        cairo_paint (cr);
+        cairo_destroy (cr);
     }
 }
 
