@@ -23,7 +23,6 @@
 #include <config.h>
 
 #include <gtk/gtk.h>
-#include <gtk/gtkmarshal.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -484,6 +483,8 @@ rstto_image_list_add_file (
                         path,
                         &t_iter);
 
+                gtk_tree_path_free (path);
+
                 /** TODO: update all iterators */
                 while (iter)
                 {
@@ -757,6 +758,8 @@ cb_rstto_read_file ( gpointer user_data )
             files = g_new0 ( RsttoFile *, loader->n_files+1);
             files[0] = rstto_file_new (child_file);
 
+            g_object_unref (child_file);
+
             for (i = 0; i < loader->n_files; ++i)
             {
                 files[i+1] = loader->files[i];
@@ -769,6 +772,8 @@ cb_rstto_read_file ( gpointer user_data )
             loader->files = files;
             loader->n_files++;
         }
+
+        g_object_unref (file_info);
     }
     else
     {
@@ -987,15 +992,22 @@ static void
 rstto_image_list_iter_dispose (GObject *object)
 {
     RsttoImageListIter *iter = RSTTO_IMAGE_LIST_ITER(object);
-    if (iter->priv->r_file)
-    {
-        iter->priv->r_file = NULL;
-    }
 
-    if (iter->priv->image_list)
+    if (iter->priv)
     {
-        iter->priv->image_list->priv->iterators = g_slist_remove (iter->priv->image_list->priv->iterators, iter);
-        iter->priv->image_list= NULL;
+        if (iter->priv->r_file)
+        {
+            iter->priv->r_file = NULL;
+        }
+
+        if (iter->priv->image_list)
+        {
+            iter->priv->image_list->priv->iterators = g_slist_remove (iter->priv->image_list->priv->iterators, iter);
+            iter->priv->image_list= NULL;
+        }
+
+        g_free (iter->priv);
+        iter->priv = NULL;
     }
 }
 
@@ -1355,90 +1367,10 @@ rstto_image_list_set_sort_by_date (RsttoImageList *image_list)
 static gint
 cb_rstto_image_list_image_name_compare_func (RsttoFile *a, RsttoFile *b)
 {
-    const gchar *a_base = rstto_file_get_display_name (a);
-    const gchar *b_base = rstto_file_get_display_name (b);
-    guint  ac;
-    guint  bc;
-    const gchar *ap = a_base;
-    const gchar *bp = b_base;
+    const gchar *a_collate_key = rstto_file_get_collate_key (a);
+    const gchar *b_collate_key = rstto_file_get_collate_key (b);
 
-    gint result = 0;
-    guint a_num = 0;
-    guint b_num = 0;
-
-    /* try simple (fast) ASCII comparison first */
-    for (;; ++ap, ++bp)
-    {
-        /* check if the characters differ or we have a non-ASCII char
-         */
-        ac = *((const guchar *) ap);
-        bc = *((const guchar *) bp);
-        if (ac != bc || ac == 0 || ac > 127)
-            break;
-    }
-
-    /* fallback to Unicode comparison */
-    if (G_UNLIKELY (ac > 127 || bc > 127))
-    {
-        for (;; ap = g_utf8_next_char (ap), bp = g_utf8_next_char (bp))
-        {
-            /* check if characters differ or end of string */
-            ac = g_utf8_get_char (ap);
-            bc = g_utf8_get_char (bp);
-            if (ac != bc || ac == 0)
-                break;
-        }
-    }
-
-    /* If both strings are equal, we're done */
-    if (ac == bc)
-    {
-        return 0;
-    }
-    else
-    {
-        if (G_UNLIKELY (g_ascii_isdigit (ac) || g_ascii_isdigit (bc)))
-        {
-            /* if both strings differ in a digit, we use a smarter comparison
-             * to get sorting 'file1', 'file5', 'file10' done the right way.
-             */
-            if (g_ascii_isdigit (ac) && g_ascii_isdigit (bc))
-            {
-                a_num = strtoul (ap, NULL, 10); 
-                b_num = strtoul (bp, NULL, 10); 
-
-                if (a_num < b_num)
-                    result = -1;
-                if (a_num > b_num)
-                    result = 1;
-            }
-
-            if (ap > a_base &&
-                bp > b_base &&
-                g_ascii_isdigit (*(ap -1)) &&
-                g_ascii_isdigit (*(bp -1)) )
-            {
-                a_num = strtoul (ap-1, NULL, 10); 
-                b_num = strtoul (bp-1, NULL, 10); 
-
-                if (a_num < b_num)
-                    result = -1;
-                if (a_num > b_num)
-                    result = 1;
-            }
-        }
-    }
-
-    if (result == 0)
-    {
-        if (ac > bc)
-            result = 1;
-        if (ac < bc)
-            result = -1;
-    }
-
-
-    return result;
+    return g_strcmp0(a_collate_key, b_collate_key);
 }
 
 /**
@@ -1725,6 +1657,7 @@ cb_rstto_thumbnailer_ready(
         gtk_tree_model_get_iter (GTK_TREE_MODEL (image_list), &iter, path_);
 
         gtk_tree_model_row_changed (GTK_TREE_MODEL(image_list), path_, &iter);
+        gtk_tree_path_free (path_);
     }
 }
 
