@@ -19,7 +19,6 @@
 
 #include <config.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkmarshal.h>
 #include <string.h>
 #include <math.h>
 
@@ -182,30 +181,36 @@ rstto_monitor_chooser_realize(GtkWidget *widget)
 {
     GdkWindowAttr attributes;
     gint attributes_mask;
+    GtkAllocation allocation;
+    GdkWindow *window;
+    GtkStyle *style;
 
     g_return_if_fail (widget != NULL);
     g_return_if_fail (RSTTO_IS_MONITOR_CHOOSER (widget));
 
-    GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+    gtk_widget_set_realized (widget, TRUE);
 
-    attributes.x = widget->allocation.x;
-    attributes.y = widget->allocation.y;
-    attributes.width = widget->allocation.width;
-    attributes.height = widget->allocation.height;
+    gtk_widget_get_allocation (widget, &allocation);
+
+    attributes.x = allocation.x;
+    attributes.y = allocation.y;
+    attributes.width = allocation.width;
+    attributes.height = allocation.height;
     attributes.wclass = GDK_INPUT_OUTPUT;
     attributes.window_type = GDK_WINDOW_CHILD;
-    attributes.event_mask = gtk_widget_get_events (widget) | 
-    GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK;
+    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK;
     attributes.visual = gtk_widget_get_visual (widget);
     attributes.colormap = gtk_widget_get_colormap (widget);
 
     attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
-    widget->window = gdk_window_new (gtk_widget_get_parent_window(widget), &attributes, attributes_mask);
+    window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
+    gtk_widget_set_window (widget, window);
 
-    widget->style = gtk_style_attach (widget->style, widget->window);
-    gdk_window_set_user_data (widget->window, widget);
+    style = gtk_style_attach (gtk_widget_get_style (widget), window);
+    gtk_widget_set_style (widget, style);
+    gdk_window_set_user_data (window, widget);
 
-    gtk_style_set_background (widget->style, widget->window, GTK_STATE_ACTIVE);
+    gtk_style_set_background (gtk_widget_get_style (widget), window, GTK_STATE_ACTIVE);
 }
 
 
@@ -219,14 +224,14 @@ rstto_monitor_chooser_size_request(GtkWidget *widget, GtkRequisition *requisitio
 static void
 rstto_monitor_chooser_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
-    widget->allocation = *allocation;
-    if (GTK_WIDGET_REALIZED (widget))
+    gtk_widget_set_allocation (widget, allocation);
+    if (gtk_widget_get_realized (widget))
     {
-        gdk_window_move_resize (widget->window,
-            allocation->x,
-            allocation->y,
-            allocation->width,
-            allocation->height);
+        gdk_window_move_resize (gtk_widget_get_window (widget),
+                allocation->x,
+                allocation->y,
+                allocation->width,
+                allocation->height);
     }
 }
 
@@ -241,23 +246,26 @@ static gboolean
 rstto_monitor_chooser_paint(GtkWidget *widget)
 {
     RsttoMonitorChooser *chooser = RSTTO_MONITOR_CHOOSER (widget);
-    cairo_t *ctx = gdk_cairo_create (widget->window);
+    cairo_t *ctx = gdk_cairo_create (gtk_widget_get_window (widget));
     Monitor *monitor;
+    GtkAllocation allocation;
 
     gdouble width, height;
     gchar *label = NULL;
     gint row_width = 0;
     gint id = 0;
 
+    gtk_widget_get_allocation (widget, &allocation);
+
     gdk_cairo_set_source_color (
             ctx,
-            &(widget->style->bg[GTK_STATE_NORMAL]));
+            &(gtk_widget_get_style (widget)->bg[GTK_STATE_NORMAL]));
     cairo_rectangle (
             ctx,
             0.0,
             0.0,
-            (gdouble)widget->allocation.width,
-            (gdouble)widget->allocation.height);
+            (gdouble)allocation.width,
+            (gdouble)allocation.height);
     cairo_fill (ctx);
 
     if (chooser->priv->n_monitors > 1)
@@ -271,12 +279,12 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
             {
                 if (monitor->width > monitor->height)
                 {
-                    width = widget->allocation.width*0.4;
+                    width = allocation.width*0.4;
                     height = width;
                 } 
                 else
                 {
-                    height = widget->allocation.width*0.4;
+                    height = allocation.width*0.4;
                     width = height;
                 }
                 label = g_strdup_printf("%d", id+1);
@@ -284,8 +292,8 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
                 paint_monitor (
                         widget,
                         ctx,
-                        ((gdouble)widget->allocation.width/4) - (width/2.0),
-                        ((gdouble)widget->allocation.height - height)/2.0,
+                        ((gdouble)allocation.width/4) - (width/2.0),
+                        ((gdouble)allocation.height - height)/2.0,
                         width,
                         height,
                         label,
@@ -300,12 +308,12 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
 
                 if (monitor->width > monitor->height)
                 {
-                    width = widget->allocation.width*(0.4/((gdouble)row_width+1));
+                    width = allocation.width*(0.4/((gdouble)row_width+1));
                     height = width;
                 } 
                 else
                 {
-                    height = widget->allocation.width*(0.4/chooser->priv->n_monitors);
+                    height = allocation.width*(0.4/chooser->priv->n_monitors);
                     width = height;
                 }
             
@@ -317,11 +325,11 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
                     paint_monitor (
                             widget,
                             ctx,
-                            ((gdouble)widget->allocation.width/2)+
-                                (((gdouble)widget->allocation.width/2)/
+                            ((gdouble)allocation.width/2)+
+                                (((gdouble)allocation.width/2)/
                                 (row_width+1))*(id%(row_width)+1)-
                                 (width/2.0),
-                            ((gdouble)widget->allocation.height/
+                            ((gdouble)allocation.height/
                                 (row_width+2)*(id/row_width+1))-
                                 (height/2.0),
                             width,
@@ -335,11 +343,11 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
                     paint_monitor (
                             widget,
                             ctx,
-                            ((gdouble)widget->allocation.width/2)+
-                                (((gdouble)widget->allocation.width/2)/
+                            ((gdouble)allocation.width/2)+
+                                (((gdouble)allocation.width/2)/
                                 (row_width+1))*((id-1)%(row_width)+1)-
                                 (width/2.0),
-                            ((gdouble)widget->allocation.height/
+                            ((gdouble)allocation.height/
                                 (row_width+2)*((id-1)/row_width+1))-
                                 (height/2.0),
                             width,
@@ -372,8 +380,8 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
             paint_monitor (
                     widget,
                     ctx,
-                    ((gdouble)widget->allocation.width - width)/2.0,
-                    ((gdouble)widget->allocation.height - height)/2.0,
+                    ((gdouble)allocation.width - width)/2.0,
+                    ((gdouble)allocation.height - height)/2.0,
                     width,
                     height,
                     "1",
@@ -472,13 +480,13 @@ paint_monitor ( GtkWidget *widget,
     /* Fill the background-color */
     gdk_cairo_set_source_color (
             cr,
-            &(widget->style->base[GTK_STATE_NORMAL]));
+            &(gtk_widget_get_style (widget)->base[GTK_STATE_NORMAL]));
     cairo_fill_preserve (cr);
 
     /* Paint the outside border */
     gdk_cairo_set_source_color (
             cr,
-            &(widget->style->fg[GTK_STATE_NORMAL]));
+            &(gtk_widget_get_style (widget)->fg[GTK_STATE_NORMAL]));
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
@@ -519,11 +527,11 @@ paint_monitor ( GtkWidget *widget,
     cairo_close_path (cr);
     gdk_cairo_set_source_color (
             cr,
-            &(widget->style->base[GTK_STATE_NORMAL]));
+            &(gtk_widget_get_style (widget)->base[GTK_STATE_NORMAL]));
     cairo_fill_preserve (cr);
     gdk_cairo_set_source_color (
             cr,
-            &(widget->style->fg[GTK_STATE_NORMAL]));
+            &(gtk_widget_get_style (widget)->fg[GTK_STATE_NORMAL]));
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
@@ -536,7 +544,7 @@ paint_monitor ( GtkWidget *widget,
     cairo_close_path (cr);
     gdk_cairo_set_source_color (
             cr,
-            &(widget->style->fg[GTK_STATE_NORMAL]));
+            &(gtk_widget_get_style (widget)->fg[GTK_STATE_NORMAL]));
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
@@ -698,16 +706,16 @@ rstto_monitor_chooser_set_image_surface (
     {
         if (monitor->image_surface)
         {
-            cairo_surface_destroy(monitor->image_surface);
+            cairo_surface_destroy (monitor->image_surface);
         }
 
         monitor->image_surface = surface;
 
         retval = monitor_id;
     }
-    if (GTK_WIDGET_REALIZED (GTK_WIDGET(chooser)))
+    if (gtk_widget_get_realized (GTK_WIDGET (chooser)))
     {
-        rstto_monitor_chooser_paint (GTK_WIDGET(chooser));
+        rstto_monitor_chooser_paint (GTK_WIDGET (chooser));
     }
 
     return retval;
@@ -729,28 +737,30 @@ cb_rstto_button_press_event (
     gint row_width = 0;
     gint id = 0;
     gint width, height;
+    GtkAllocation allocation;
     
     if (chooser->priv->n_monitors > 1)
     {
         row_width = sqrt (chooser->priv->n_monitors);
 
-        width = widget->allocation.width*(0.4/((gdouble)row_width+1));
+        gtk_widget_get_allocation (widget, &allocation);
+        width = allocation.width*(0.4/((gdouble)row_width+1));
         height = width;
 
         for (id = 0; id < chooser->priv->n_monitors; ++id)
         {
-            if ( (event->x > ((gdouble)widget->allocation.width/2)+
-                                (((gdouble)widget->allocation.width/2)/
+            if ( (event->x > ((gdouble)allocation.width/2)+
+                                (((gdouble)allocation.width/2)/
                                 (row_width+1))*(id%(row_width)+1)-
                                 (width/2.0)) &&
-                 (event->x < ((gdouble)widget->allocation.width/2)+
-                                (((gdouble)widget->allocation.width/2)/
+                 (event->x < ((gdouble)allocation.width/2)+
+                                (((gdouble)allocation.width/2)/
                                 (row_width+1))*(id%(row_width)+1)+
                                 (width/2.0)) &&
-                 (event->y > ((gdouble)widget->allocation.height/
+                 (event->y > ((gdouble)allocation.height/
                                 (row_width+2)*(id/row_width+1)-
                                 (height/2.0))) &&
-                 (event->y < ((gdouble)widget->allocation.height/
+                 (event->y < ((gdouble)allocation.height/
                                 (row_width+2)*(id/row_width+1)+
                                 (height/2.0))))
             {
