@@ -154,12 +154,12 @@ rstto_privacy_dialog_init (RsttoPrivacyDialog *dialog)
 
     dialog->priv->cleanup_vbox = gtk_vbox_new(FALSE, 0);
     dialog->priv->cleanup_frame = xfce_gtk_frame_box_new_with_content(_("Cleanup"), dialog->priv->cleanup_vbox);
-    dialog->priv->cleanup_timeframe_combo = gtk_combo_box_new_text();
-    gtk_combo_box_insert_text(GTK_COMBO_BOX(dialog->priv->cleanup_timeframe_combo), 0, _("Last Hour"));
-    gtk_combo_box_insert_text(GTK_COMBO_BOX(dialog->priv->cleanup_timeframe_combo), 1, _("Last Two Hours"));
-    gtk_combo_box_insert_text(GTK_COMBO_BOX(dialog->priv->cleanup_timeframe_combo), 2, _("Last Four Hours"));
-    gtk_combo_box_insert_text(GTK_COMBO_BOX(dialog->priv->cleanup_timeframe_combo), 3, _("Today"));
-    gtk_combo_box_insert_text(GTK_COMBO_BOX(dialog->priv->cleanup_timeframe_combo), 4, _("Everything"));
+    dialog->priv->cleanup_timeframe_combo = gtk_combo_box_text_new();
+    gtk_combo_box_text_insert_text(GTK_COMBO_BOX_TEXT(dialog->priv->cleanup_timeframe_combo), 0, _("Last Hour"));
+    gtk_combo_box_text_insert_text(GTK_COMBO_BOX_TEXT(dialog->priv->cleanup_timeframe_combo), 1, _("Last Two Hours"));
+    gtk_combo_box_text_insert_text(GTK_COMBO_BOX_TEXT(dialog->priv->cleanup_timeframe_combo), 2, _("Last Four Hours"));
+    gtk_combo_box_text_insert_text(GTK_COMBO_BOX_TEXT(dialog->priv->cleanup_timeframe_combo), 3, _("Today"));
+    gtk_combo_box_text_insert_text(GTK_COMBO_BOX_TEXT(dialog->priv->cleanup_timeframe_combo), 4, _("Everything"));
     g_signal_connect (G_OBJECT (dialog->priv->cleanup_timeframe_combo), 
                       "changed", (GCallback)cb_rstto_privacy_dialog_combobox_timeframe_changed, dialog);
     gtk_combo_box_set_active(GTK_COMBO_BOX(dialog->priv->cleanup_timeframe_combo), 0);
@@ -171,7 +171,7 @@ rstto_privacy_dialog_init (RsttoPrivacyDialog *dialog)
     gtk_box_pack_start (GTK_BOX (display_main_hbox), 
                         dialog->priv->cleanup_timeframe_combo, FALSE, FALSE, 0);
 
-    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 
+    gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                        dialog->priv->cleanup_frame);
 
     gtk_widget_show_all (dialog->priv->cleanup_frame);
@@ -179,8 +179,8 @@ rstto_privacy_dialog_init (RsttoPrivacyDialog *dialog)
     /* Window should not be resizable */
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 
-    gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-    gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_APPLY, GTK_RESPONSE_OK);
+    gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Cancel"), GTK_RESPONSE_CANCEL);
+    gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Apply"), GTK_RESPONSE_OK);
 }
 
 static void
@@ -458,7 +458,7 @@ rstto_privacy_dialog_new (GtkWindow *parent, GtkRecentManager *recent_manager)
 {
     GtkWidget *dialog = g_object_new (RSTTO_TYPE_PRIVACY_DIALOG,
                                       "title", _("Clear private data"),
-                                      "icon-name", GTK_STOCK_CLEAR,
+                                      "icon-name", "edit-clear",
                                       "recent-manager", recent_manager,
                                       NULL);
 
