@@ -325,7 +325,7 @@ rstto_properties_dialog_init (RsttoPropertiesDialog *dialog)
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 
 
-    gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_OK);
+    gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_OK);
 }
 
 static void
@@ -436,7 +436,22 @@ properties_dialog_set_file (
         file_uri_checksum = g_compute_checksum_for_string (G_CHECKSUM_MD5, file_uri, strlen (file_uri));
         filename = g_strconcat (file_uri_checksum, ".png", NULL);
 
-        thumbnail_path = g_build_path ("/", g_get_home_dir(), ".thumbnails", "normal", filename, NULL);
+        /* build and check if the thumbnail is in the new location */
+        thumbnail_path = g_build_path ("/", g_get_user_cache_dir(), "thumbnails", "normal", filename, NULL);
+
+        if(!g_file_test (thumbnail_path, G_FILE_TEST_EXISTS))
+        {
+            /* Fallback to old version */
+            g_free (thumbnail_path);
+
+            thumbnail_path = g_build_path ("/", g_get_home_dir(), ".thumbnails", "normal", filename, NULL);
+            if(!g_file_test (thumbnail_path, G_FILE_TEST_EXISTS))
+            {
+                /* Thumbnail doesn't exist in either spot */
+                g_free (thumbnail_path);
+                thumbnail_path = NULL;
+            }
+        }
         pixbuf = gdk_pixbuf_new_from_file_at_scale (thumbnail_path, 96, 96, TRUE, NULL);
         if (NULL != pixbuf)
         {
@@ -624,7 +639,7 @@ rstto_properties_dialog_new (
     gchar *title = g_strdup_printf (_("%s - Properties"), rstto_file_get_display_name (file));
     GtkWidget *dialog = g_object_new (RSTTO_TYPE_PROPERTIES_DIALOG,
                                       "title", title,
-                                      "icon-name", GTK_STOCK_PROPERTIES,
+                                      "icon-name", "document-properties",
                                       "file", file,
                                       NULL);
     g_free (title);
