@@ -189,11 +189,12 @@ rstto_xfce_wallpaper_manager_check_running (RsttoWallpaperManager *self)
     Atom xfce_selection_atom;
     GdkScreen *gdk_screen = gdk_screen_get_default();
     gint xscreen = gdk_screen_get_number(gdk_screen);
+    Display *gdk_display = gdk_x11_get_default_xdisplay();
 
     g_snprintf(selection_name, 100, XFDESKTOP_SELECTION_FMT, xscreen);
 
     xfce_selection_atom = XInternAtom (gdk_display, selection_name, False);
-    if((XGetSelectionOwner(GDK_DISPLAY(), xfce_selection_atom)))
+    if((XGetSelectionOwner(gdk_display, xfce_selection_atom)))
     {
         return TRUE;
     }
@@ -404,11 +405,11 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             _("Set as wallpaper"),
             NULL,
             0,
-            GTK_STOCK_CANCEL,
+            _("_Cancel"),
             GTK_RESPONSE_CANCEL,
-            GTK_STOCK_APPLY,
+            _("_Apply"),
             GTK_RESPONSE_APPLY,
-            GTK_STOCK_OK,
+            _("_OK"),
             GTK_RESPONSE_OK,
             NULL);
     vbox = gtk_dialog_get_content_area ( GTK_DIALOG (manager->priv->dialog));
@@ -443,7 +444,7 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
     saturation_slider = gtk_hscale_new (
             GTK_ADJUSTMENT (manager->priv->saturation_adjustment));
     manager->priv->monitor_chooser = rstto_monitor_chooser_new ();
-    manager->priv->style_combo = gtk_combo_box_new_text();
+    manager->priv->style_combo = gtk_combo_box_text_new ();
 
     gtk_table_set_row_spacing (GTK_TABLE(image_prop_table), 1, 4);
 
@@ -552,23 +553,23 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             0,
             0);
 
-    gtk_combo_box_append_text (
-            GTK_COMBO_BOX (manager->priv->style_combo),
+    gtk_combo_box_text_append_text (
+            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Auto"));
-    gtk_combo_box_append_text (
-            GTK_COMBO_BOX (manager->priv->style_combo),
+    gtk_combo_box_text_append_text (
+            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Centered"));
-    gtk_combo_box_append_text (
-            GTK_COMBO_BOX (manager->priv->style_combo),
+    gtk_combo_box_text_append_text (
+            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Tiled"));
-    gtk_combo_box_append_text (
-            GTK_COMBO_BOX (manager->priv->style_combo),
+    gtk_combo_box_text_append_text (
+            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Stretched"));
-    gtk_combo_box_append_text (
-            GTK_COMBO_BOX (manager->priv->style_combo),
+    gtk_combo_box_text_append_text (
+            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Scaled"));
-    gtk_combo_box_append_text (
-            GTK_COMBO_BOX (manager->priv->style_combo),
+    gtk_combo_box_text_append_text (
+            GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Zoomed"));
 
     gtk_combo_box_set_active (
@@ -634,13 +635,13 @@ rstto_xfce_wallpaper_manager_dispose (GObject *object)
 {
     RsttoXfceWallpaperManager *xfce_wallpaper_manager = RSTTO_XFCE_WALLPAPER_MANAGER (object);
 
-    if (xfce_wallpaper_manager->priv->channel)
-    {
-        g_object_unref (xfce_wallpaper_manager->priv->channel);
-        xfce_wallpaper_manager->priv->channel = NULL;
-    }
     if (xfce_wallpaper_manager->priv)
     {
+        if (xfce_wallpaper_manager->priv->channel)
+        {
+            g_object_unref (xfce_wallpaper_manager->priv->channel);
+            xfce_wallpaper_manager->priv->channel = NULL;
+        }
         g_free (xfce_wallpaper_manager->priv);
         xfce_wallpaper_manager->priv = NULL;
     }
